package
Version:
v0.17.5
Opens a new window with list of versions in this module.
Published: Aug 22, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Error struct {
Message string
}
type File struct {
Path string `json:"path"`
MediaType string `json:"media_type"`
Kind string `json:"kind"`
Text string `json:"text,omitempty"`
DataURL string `json:"data_url,omitempty"`
Size int64 `json:"size"`
}
type GitDiff struct {
Path string `json:"path"`
Diff string `json:"diff"`
}
type GitFile struct {
Path string `json:"path"`
OriginalPath string `json:"original_path,omitempty"`
Status string `json:"status"`
}
type GitStatus struct {
Available bool `json:"available"`
Branch string `json:"branch,omitempty"`
Files []GitFile `json:"files"`
Truncated bool `json:"truncated,omitempty"`
}
type Tree struct {
Root string `json:"root"`
Entries []TreeEntry `json:"entries"`
Truncated bool `json:"truncated,omitempty"`
}
type TreeEntry struct {
Path string `json:"path"`
Name string `json:"name"`
Kind string `json:"kind"`
Size int64 `json:"size,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.